@@ -10,8 +10,8 @@ __credits__  = "Yegor Shershnev"
 __license__ = "GPL"
 __version__ = "$Revision: 12897 $"
 
-from eventannotation.interfaces import IEventAnnotation
-from anytitlesubscriberbase import AnyTitileSubscriberBase
+from interfaces import IEventAnnotation
+from ng.adapter.ianytitle.anytitlesubscriberbase import AnyTitileSubscriberBase
 
 class EventAnnotation2TitleSubscriber( AnyTitileSubscriberBase ) :
 
